@@ -1,5 +1,10 @@
+import io
+import json
+import pathlib
+
 from drf_yasg.utils import swagger_auto_schema
 from rest_framework.decorators import action
+from rest_framework.exceptions import APIException, ValidationError
 from rest_framework.request import Request
 from rest_framework.response import Response
 
@@ -7,14 +12,22 @@ from django_large_image import tilesource
 from django_large_image.rest import params
 from django_large_image.rest.base import LargeImageMixinBase
 
+try:
+    import tifftools
+    from tifftools.exceptions import TifftoolsError
+except ImportError:  # pragma: no cover
+    tifftools = None
+    TifftoolsError = None
+
 metadata_summary = 'Returns tile metadata.'
-metadata_parameters = [params.projection]
+metadata_parameters = params.BASE
 metadata_internal_summary = 'Returns additional known metadata about the tile source.'
-metadata_internal_parameters = [params.projection]
+metadata_internal_parameters = params.BASE
 bands_summary = 'Returns bands information.'
-bands_parameters = [params.projection]
+bands_parameters = params.BASE
 band_summary = 'Returns single band information.'
-band_parameters = [params.projection, params.band]
+band_parameters = params.BASE + [params.band]
+tiffdump_summary = 'Returns tifftools tiffdump JSON. This will raise a `ValidationError` if the image is not a Tiff.'
 
 
 class MetaDataMixin(LargeImageMixinBase):
@@ -63,6 +76,32 @@ class MetaDataMixin(LargeImageMixinBase):
         metadata = source.getOneBandInformation(band)
         return Response(metadata)
 
+    @swagger_auto_schema(
+        method='GET',
+        operation_summary=tiffdump_summary,
+    )
+    @action(detail=False)
+    def tiffdump(self, request: Request, pk: int = None) -> Response:
+        if tifftools is None:  # pragma: no cover
+            raise APIException('`tifftools` is not installed on the server.')
+        source = self.get_tile_source(request, pk, style=False)
+        # This will only work for local files (path on disk)
+        path = source._getLargeImagePath()
+        try:
+            if not pathlib.Path(path).exists():
+                raise OSError  # pragma: no cover
+        except OSError:
+            raise APIException(
+                'The image path is not local and tifftools will not be able to open this image.'
+            )
+        output = io.StringIO()
+        try:
+            tifftools.tiff_dump(path, dest=output, outformat='json')
+        except (TifftoolsError, OSError) as e:
+            raise ValidationError(str(e))
+        output.seek(0)
+        return Response(json.loads(output.read()))
+
 
 class MetaDataDetailMixin(MetaDataMixin):
     @swagger_auto_schema(
@@ -100,3 +139,11 @@ class MetaDataDetailMixin(MetaDataMixin):
     @action(detail=True)
     def band(self, request: Request, pk: int = None) -> Response:
         return super().band(request, pk)
+
+    @swagger_auto_schema(
+        method='GET',
+        operation_summary=tiffdump_summary,
+    )
+    @action(detail=True)
+    def tiffdump(self, request: Request, pk: int = None) -> Response:
+        return super().tiffdump(request, pk)
