@@ -12,11 +12,26 @@ from django_large_image import utilities
 
 
 def get_tilesource_from_path(
-    path: str, projection: str = None, style: str = None, encoding: str = None
+    path: str,
+    projection: Optional[str] = None,
+    style: Optional[str] = None,
+    encoding: Optional[str] = None,
+    source: Optional[str] = None,
 ) -> FileTileSource:
-    if encoding is None:
+    if not encoding:
         encoding = 'PNG'
-    return large_image.open(str(path), projection=projection, style=style, encoding=encoding)
+    if source:
+        large_image.tilesource.loadTileSources()
+        sources = large_image.tilesource.AvailableTileSources
+        try:
+            reader = sources[source]
+        except KeyError:
+            raise ValidationError(
+                f'{source!r} is not a valid source. Try one of: {list(sources.keys())}'
+            )
+    else:
+        reader = large_image.open
+    return reader(str(path), projection=projection, style=style, encoding=encoding)
 
 
 def is_geospatial(source: FileTileSource) -> bool:
@@ -84,18 +99,18 @@ def get_region(
 ) -> Tuple[pathlib.Path, str]:
     if isinstance(units, str):
         units = units.lower()
-    if encoding is None and is_geospatial(source):
+    if not encoding and is_geospatial(source):
         # Use tiled encoding by default for geospatial rasters
         #   output will be a tiled TIF
         encoding = 'TILED'
-    elif encoding is None:
+    elif not encoding:
         # Use JPEG encoding by default for nongeospatial rasters
         encoding = 'JPEG'
     if is_geospatial(source) and units not in [
         'pixels',
         'pixel',
     ]:
-        if units is None:
+        if not units:
             units = 'EPSG:4326'
         region = dict(left=left, right=right, bottom=bottom, top=top, units=units)
         return _get_region(source, region, encoding)
@@ -108,10 +123,10 @@ def get_region(
 
 def format_to_encoding(format: Optional[str]) -> str:
     """Translate format extension (e.g., `tiff`) to encoding (e.g., `TILED`)."""
-    if format is None:
+    if not format:
         return 'PNG'
     if format.lower() not in ['tif', 'tiff', 'png', 'jpeg', 'jpg']:
-        raise ValidationError(f'Format `{format}` is not valid. Try `png`, `jpeg`, or `tif`')
+        raise ValidationError(f'Format {format!r} is not valid. Try `png`, `jpeg`, or `tif`')
     if format.lower() in ['tif', 'tiff']:
         return 'TILED'
     return format.upper()  # jpeg, png
